@@ -30,7 +30,7 @@ class Tool : public AbstractSourceTool
     Q_OBJECT
 
 public:
-    explicit Tool(QObject *parent = nullptr);
+    explicit Tool();
 
     ~Tool() override;
 
@@ -39,7 +39,9 @@ public:
 
 public: // AbstractSourceTool API
     void setOrigin(const QUrl &origin) override;
-    QWidget *widget() override;
+    QWidget *widget() const override;
+    void switchToPickView() override;
+    bool isInPickView() const override;
 
 private:
     void handleImageLoadResult(KJob *job);
@@ -47,7 +49,7 @@ private:
 
 private:
     std::unique_ptr<ImageSelectTool> m_imageSelectTool;
-    Widget *m_widget;
+    const std::unique_ptr<Widget> m_widget;
 };
 
 }
